@@ -225,16 +225,16 @@ class DiscordBot(MultiBot[Bot]):
                 if (path_suffix := pathlib.Path(media.url).suffix) and len(path_suffix) <= constants.MAX_FILE_EXTENSION_LENGHT:
                     return discord.File(media.url)
                 else:
-                    return discord.File(media.url, filename=f'bot_media.{media.type_.extension}')
+                    return discord.File(media.url, filename=f'bot_media.{media.extension}')
             elif not media.bytes_:
                 media.bytes_ = await flanautils.get_request(media.url)
 
         if bytes_ := media.bytes_:
             if media.type_ is MediaType.GIF:
-                bytes_ = await flanautils.mp4_to_gif(bytes_)
+                bytes_ = await flanautils.to_gif(bytes_)
             if len(bytes_) > constants.DISCORD_MEDIA_MAX_BYTES:
                 raise LimitError
-            file = discord.File(fp=io.BytesIO(bytes_), filename=f'bot_media.{media.type_.extension}')
+            file = discord.File(fp=io.BytesIO(bytes_), filename=f'bot_media.{media.extension}')
         else:
             return
 
@@ -301,7 +301,7 @@ class DiscordBot(MultiBot[Bot]):
             try:
                 await chat.original_object.delete_messages(chunk)
             except discord.errors.HTTPException:
-                raise LimitError(f'Solo puedo eliminar mensajes con menos de 14 días  {random.choice(constants.SAD_EMOJIS)}')
+                raise LimitError(f'Solo puedo eliminar mensajes con menos de 14 días {random.choice(constants.SAD_EMOJIS)}')
 
     @return_if_first_empty(exclude_self_types='DiscordBot', globals_=globals())
     async def delete_message(self, message_to_delete: int | str | Message, chat: int | str | Chat | Message = None):  # todo2 test
