@@ -210,28 +210,31 @@ class TelegramBot(MultiBot[TelegramClient]):
 
     @staticmethod
     @return_if_first_empty
-    def _prepare_media_to_send(media: Media, prefer_bytes=False) -> str | io.BytesIO | None:
+    async def _prepare_media_to_send(media: Media, prefer_bytes=False, inline_=False) -> str | io.BytesIO | None:
         def url_file() -> str | None:
             if not media.url:
                 return
 
             if not pathlib.Path(media.url).is_file() and media.source is Source.INSTAGRAM and (not (path_suffix := pathlib.Path(media.url).suffix) or len(path_suffix) > constants.MAX_FILE_EXTENSION_LENGHT):
-                return f'{media.url}.{media.type_.extension}'
+                return f'{media.url}.{media.extension}'
             else:
                 return media.url
 
-        def bytes_file() -> io.BytesIO | None:
-            if not media.url:
+        async def bytes_file() -> io.BytesIO | None:
+            if not media.bytes_:
                 return
 
-            file_ = io.BytesIO(media.bytes_)
-            file_.name = f'bot_media.{media.type_.extension}'
+            bytes_ = media.bytes_
+            if inline_ and media.type_ is MediaType.AUDIO:
+                bytes_ = await flanautils.add_metadata(bytes_, {'title': 'Audio'}, overwrite=False)
+            file_ = io.BytesIO(bytes_)
+            file_.name = f'bot_media.{media.extension}'
             return file_
 
         if prefer_bytes:
-            file = bytes_file() or url_file()
+            file = await bytes_file() or url_file()
         else:
-            file = url_file() or bytes_file()
+            file = url_file() or await bytes_file()
 
         return file
 
@@ -393,7 +396,7 @@ class TelegramBot(MultiBot[TelegramClient]):
         send_as_file: bool = None,
         edit=False,
     ) -> Message | None:
-        file = self._prepare_media_to_send(media)
+        file = await self._prepare_media_to_send(media)
         telegram_buttons = None
 
         if buttons:
@@ -456,35 +459,38 @@ class TelegramBot(MultiBot[TelegramClient]):
             case Message() as message_to_reply:
                 reply_to = message_to_reply.original_object
 
-        try:
-            original_message = await self.client.send_message(chat.original_object, text, buttons=telegram_buttons, reply_to=reply_to, silent=silent, **kwargs)
-        except telethon.errors.rpcerrorlist.WebpageCurlFailedError:
-            if media.bytes_:
-                kwargs['file'] = self._prepare_media_to_send(media, prefer_bytes=True)
+        with flanautils.suppress_stderr():
+            try:
                 original_message = await self.client.send_message(chat.original_object, text, buttons=telegram_buttons, reply_to=reply_to, silent=silent, **kwargs)
-            else:
-                raise
-        except (telethon.errors.rpcerrorlist.PeerIdInvalidError, telethon.errors.rpcerrorlist.UserIsBlockedError):
-            return
+            except telethon.errors.rpcerrorlist.WebpageCurlFailedError:
+                if media.bytes_:
+                    kwargs['file'] = await self._prepare_media_to_send(media, prefer_bytes=True)
+                    original_message = await self.client.send_message(chat.original_object, text, buttons=telegram_buttons, reply_to=reply_to, silent=silent, **kwargs)
+                else:
+                    raise
+            except (telethon.errors.rpcerrorlist.PeerIdInvalidError, telethon.errors.rpcerrorlist.UserIsBlockedError):
+                return
 
         return await self._create_bot_message_from_telegram_bot_message(original_message, media, chat, buttons, buttons_key, contents)
 
     @inline
     async def send_inline_results(self, message: Message):
-        def create_result(media: Media, prefer_bytes=False) -> telethon.types.InputBotInlineResultPhoto | telethon.types.InputBotInlineResultDocument:
-            file = self._prepare_media_to_send(media, prefer_bytes)
-            if media.type_ is MediaType.IMAGE:
-                return message.original_event.builder.photo(file)
-            else:
-                return message.original_event.builder.document(file, title=media.type_.name.title(), type=media.type_.name.lower())
+        async def create_result(media: Media, prefer_bytes=False) -> telethon.types.InputBotInlineResultPhoto | telethon.types.InputBotInlineResultDocument:
+            file = await self._prepare_media_to_send(media, prefer_bytes, inline_=True)
+            match media.type_:
+                case MediaType.IMAGE:
+                    return message.original_event.builder.photo(file)
+                case _:
+                    return message.original_event.builder.document(file, title=media.type_.name.title(), type=media.type_.name.lower())
 
-        try:
+        with flanautils.suppress_stderr():
             try:
-                await message.original_event.answer([create_result(media) for media in message.contents['inline_media']])
-            except telethon.errors.rpcerrorlist.WebpageCurlFailedError:
-                await message.original_event.answer([create_result(media, prefer_bytes=True) for media in message.contents['inline_media']])
-        except (KeyError, telethon.errors.rpcerrorlist.QueryIdInvalidError):
-            pass
+                try:
+                    await message.original_event.answer([await create_result(media) for media in message.contents['inline_media']])
+                except telethon.errors.rpcerrorlist.WebpageCurlFailedError:
+                    await message.original_event.answer([await create_result(media, prefer_bytes=True) for media in message.contents['inline_media']])
+            except (KeyError, telethon.errors.rpcerrorlist.QueryIdInvalidError):
+                pass
 
     def start(self):
         async def start_():
